@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminPackageManager.pm - manage software packages
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminPackageManager.pm,v 1.81 2009/07/30 14:40:13 martin Exp $
+# $Id: AdminPackageManager.pm,v 1.98 2011/01/30 09:49:39 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::Package;
 use Kernel::System::Web::UploadCache;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.81 $) [1];
+$VERSION = qw($Revision: 1.98 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -28,14 +28,14 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(ParamObject DBObject LayoutObject LogObject ConfigObject MainObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+    for my $Needed (qw(ParamObject DBObject LayoutObject LogObject ConfigObject MainObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
         }
     }
 
-    $Self->{PackageObject}    = Kernel::System::Package->new(%Param);
-    $Self->{UploadCachObject} = Kernel::System::Web::UploadCache->new(%Param);
+    $Self->{PackageObject}     = Kernel::System::Package->new(%Param);
+    $Self->{UploadCacheObject} = Kernel::System::Web::UploadCache->new(%Param);
 
     return $Self;
 }
@@ -44,6 +44,7 @@ sub Run {
     my ( $Self, %Param ) = @_;
 
     my $Source = $Self->{UserRepository} || '';
+    my %Errors;
 
     # ------------------------------------------------------------ #
     # check mod perl version and Apache::Reload
@@ -64,22 +65,18 @@ sub Run {
                 if ( !$ApacheReload ) {
                     return $Self->{LayoutObject}->ErrorScreen(
                         Message =>
-                            'Sorry, Apache::Reload or Apache2::Reload is needed as PerlModule and ".
-                            "PerlInitHandler in Apache config file. See also scripts/apache2-httpd.include.conf!'
+                            'Sorry, Apache::Reload is needed as PerlModule and '
+                            .
+                            'PerlInitHandler in Apache config file. See also scripts/apache2-httpd.include.conf. '
+                            .
+                            'Alternatively, you can use the cmd tool bin/otrs.PackageManager.pl to install packages!'
                     );
                 }
             }
-            else {
-                return $Self->{LayoutObject}->ErrorScreen(
-                    Message =>
-                        'Sorry, for this interface is mod_perl2 with Apache2::Reload required. ".
-                        "Other way you need to use the cmd tool bin/opm.pl to install packages!'
-                );
-            }
         }
     }
 
-    # secure mode message (don't allow this action till secure mode is enabled)
+    # secure mode message (don't allow this action untill secure mode is enabled)
     if ( !$Self->{ConfigObject}->Get('SecureMode') ) {
         $Self->{LayoutObject}->SecureMode();
     }
@@ -106,7 +103,7 @@ sub Run {
         if ( !$Location ) {
 
         }
-        if ( ref( $Structure{Filelist} ) eq 'ARRAY' ) {
+        if ( ref $Structure{Filelist} eq 'ARRAY' ) {
             for my $Hash ( @{ $Structure{Filelist} } ) {
                 if ( $Hash->{Location} eq $Location ) {
                     $File = $Hash->{Content};
@@ -171,7 +168,7 @@ sub Run {
         my $Name    = $Self->{ParamObject}->GetParam( Param => 'Name' )    || '';
         my $Version = $Self->{ParamObject}->GetParam( Param => 'Version' ) || '';
         my $Location = $Self->{ParamObject}->GetParam( Param => 'Location' );
-        my %Frontend = ();
+        my %Frontend;
 
         # get package
         my $Package = $Self->{PackageObject}->RepositoryGet(
@@ -203,16 +200,21 @@ sub Run {
             Name => 'Package',
             Data => { %Param, %Frontend, Name => $Name, Version => $Version, },
         );
-        for (qw(DownloadLocal Rebuild Reinstall)) {
+        for my $PackageAction (qw(DownloadLocal Rebuild Reinstall)) {
             $Self->{LayoutObject}->Block(
-                Name => 'Package' . $_,
-                Data => { %Param, %Frontend, Name => $Name, Version => $Version, },
+                Name => 'Package' . $PackageAction,
+                Data => {
+                    %Param,
+                    %Frontend,
+                    Name    => $Name,
+                    Version => $Version,
+                },
             );
         }
 
         # check if file is requested
         if ($Location) {
-            if ( ref( $Structure{Filelist} ) eq 'ARRAY' ) {
+            if ( ref $Structure{Filelist} eq 'ARRAY' ) {
                 for my $Hash ( @{ $Structure{Filelist} } ) {
                     if ( $Hash->{Location} eq $Location ) {
                         return $Self->{LayoutObject}->Attachment(
@@ -224,9 +226,9 @@ sub Run {
                 }
             }
         }
-        my @DatabaseBuffer = ();
+        my @DatabaseBuffer;
         for my $Key ( sort keys %Structure ) {
-            if ( ref( $Structure{$Key} ) eq 'HASH' ) {
+            if ( ref $Structure{$Key} eq 'HASH' ) {
                 if ( $Key =~ /^(Description|Filelist)$/ ) {
                     $Self->{LayoutObject}->Block(
                         Name => "PackageItem$Key",
@@ -242,23 +244,23 @@ sub Run {
                                         Name => "PackageItemDatabase",
                                         Data => { %{$Hash}, TagName => $Key, Type => $Type },
                                     );
-                                    push( @DatabaseBuffer, $Hash );
+                                    push @DatabaseBuffer, $Hash;
                                 }
                                 else {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSub",
                                         Data => { %{$Hash}, TagName => $Key, },
                                     );
-                                    push( @DatabaseBuffer, $Hash );
+                                    push @DatabaseBuffer, $Hash;
                                 }
                             }
                             if ( $Hash->{Tag} =~ /^Table/ && $Hash->{TagType} eq 'End' ) {
-                                push( @DatabaseBuffer, $Hash );
+                                push @DatabaseBuffer, $Hash;
                                 my @SQL = $Self->{DBObject}->SQLProcessor(
                                     Database => \@DatabaseBuffer
                                 );
                                 my @SQLPost = $Self->{DBObject}->SQLProcessorPost();
-                                push( @SQL, @SQLPost );
+                                push @SQL, @SQLPost;
                                 for my $SQL (@SQL) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSQL",
@@ -277,7 +279,7 @@ sub Run {
                     );
                 }
             }
-            elsif ( ref( $Structure{$Key} ) eq 'ARRAY' ) {
+            elsif ( ref $Structure{$Key} eq 'ARRAY' ) {
                 for my $Hash ( @{ $Structure{$Key} } ) {
                     if ( $Key =~ /^(Description|ChangeLog)$/ ) {
                         $Self->{LayoutObject}->Block(
@@ -340,7 +342,7 @@ sub Run {
                                         Version => $Version,
                                         %{$Hash},
                                         Message => $DeployInfo{File}->{ $Hash->{Location} },
-                                        Image   => 'notready.png',
+                                        Icon    => 'IconNotReady',
                                     },
                                 );
                             }
@@ -352,7 +354,7 @@ sub Run {
                                         Version => $Version,
                                         %{$Hash},
                                         Message => $DeployInfo{File}->{ $Hash->{Location} },
-                                        Image   => 'notready-sw.png',
+                                        Icon    => 'IconNotReadyGrey',
                                     },
                                 );
                             }
@@ -365,7 +367,7 @@ sub Run {
                                     Version => $Version,
                                     %{$Hash},
                                     Message => 'ok',
-                                    Image   => 'ready.png',
+                                    Icon    => 'IconReady',
                                 },
                             );
                         }
@@ -385,10 +387,10 @@ sub Run {
             $Output .= $Self->{LayoutObject}->Notify(
                 Priority => 'Error',
                 Data     => "$Name $Version"
-                    . ' - $Text{"Package not correctly deployed! You should reinstall the Package again!"}',
-                Link => '$Env{"Baselink"}Action=$Env{"Action"}&Subaction=View&Name='
+                    . ' - $Text{"Package not correctly deployed! Please reinstall the package."}',
+                Link => '$Env{"Baselink"}Action=$Env{"Action"};Subaction=View;Name='
                     . $Name
-                    . '&Version='
+                    . ';Version='
                     . $Version,
             );
         }
@@ -400,7 +402,7 @@ sub Run {
                     '$Text{"Package verification failed!"} $Text{"For more info see:"} http://otrs.org/verify/',
                 Link => 'http://otrs.org/verify?Name'
                     . $Name
-                    . '&Version='
+                    . ';Version='
                     . $Version,
             );
         }
@@ -415,9 +417,9 @@ sub Run {
     # view remote package
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'ViewRemote' ) {
-        my $File     = $Self->{ParamObject}->GetParam( Param => 'File' ) || '';
+        my $File = $Self->{ParamObject}->GetParam( Param => 'File' ) || '';
         my $Location = $Self->{ParamObject}->GetParam( Param => 'Location' );
-        my %Frontend = ();
+        my %Frontend;
 
         # download package
         my $Package = $Self->{PackageObject}->PackageOnlineGet(
@@ -439,7 +441,7 @@ sub Run {
 
         # check if file is requested
         if ($Location) {
-            if ( ref( $Structure{Filelist} ) eq 'ARRAY' ) {
+            if ( ref $Structure{Filelist} eq 'ARRAY' ) {
                 for my $Hash ( @{ $Structure{Filelist} } ) {
                     if ( $Hash->{Location} eq $Location ) {
                         return $Self->{LayoutObject}->Attachment(
@@ -451,9 +453,9 @@ sub Run {
                 }
             }
         }
-        my @DatabaseBuffer = ();
+        my @DatabaseBuffer;
         for my $Key ( sort keys %Structure ) {
-            if ( ref( $Structure{$Key} ) eq 'HASH' ) {
+            if ( ref $Structure{$Key} eq 'HASH' ) {
                 if ( $Key =~ /^(Description|Filelist)$/ ) {
                     $Self->{LayoutObject}->Block(
                         Name => "PackageItem$Key",
@@ -469,23 +471,23 @@ sub Run {
                                         Name => "PackageItemDatabase",
                                         Data => { %{$Hash}, TagName => $Key, Type => $Type },
                                     );
-                                    push( @DatabaseBuffer, $Hash );
+                                    push @DatabaseBuffer, $Hash;
                                 }
                                 else {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSub",
                                         Data => { %{$Hash}, TagName => $Key, },
                                     );
-                                    push( @DatabaseBuffer, $Hash );
+                                    push @DatabaseBuffer, $Hash;
                                 }
                             }
                             if ( $Hash->{Tag} =~ /^Table/ && $Hash->{TagType} eq 'End' ) {
-                                push( @DatabaseBuffer, $Hash );
+                                push @DatabaseBuffer, $Hash;
                                 my @SQL = $Self->{DBObject}->SQLProcessor(
                                     Database => \@DatabaseBuffer
                                 );
                                 my @SQLPost = $Self->{DBObject}->SQLProcessorPost();
-                                push( @SQL, @SQLPost );
+                                push @SQL, @SQLPost;
                                 for my $SQL (@SQL) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSQL",
@@ -504,7 +506,7 @@ sub Run {
                     );
                 }
             }
-            elsif ( ref( $Structure{$Key} ) eq 'ARRAY' ) {
+            elsif ( ref $Structure{$Key} eq 'ARRAY' ) {
                 for my $Hash ( @{ $Structure{$Key} } ) {
                     if ( $Key =~ /^(Description|ChangeLog)$/ ) {
                         $Self->{LayoutObject}->Block(
@@ -712,7 +714,7 @@ sub Run {
             return $Self->{LayoutObject}->ErrorScreen( Message => 'No such package!' );
         }
 
-        # check if we have to show uninstall intro pre
+        # check if we have to show reinstall intro pre
         my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
 
         # intro screen
@@ -783,7 +785,7 @@ sub Run {
             return $Self->{LayoutObject}->ErrorScreen( Message => 'No such package!' );
         }
 
-        # check if we have to show uninstall intro pre
+        # check if we have to show reinstall intro pre
         my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
 
         # intro screen
@@ -953,13 +955,13 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'InstallUpload' ) {
         my $FormID = $Self->{ParamObject}->GetParam( Param => 'FormID' ) || '';
         my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
-            Param  => 'file_upload',
+            Param  => 'FileUpload',
             Source => 'string',
         );
 
         # save package in upload cache
         if (%UploadStuff) {
-            my $Added = $Self->{UploadCachObject}->FormIDAddFile(
+            my $Added = $Self->{UploadCacheObject}->FormIDAddFile(
                 FormID => $FormID,
                 %UploadStuff,
             );
@@ -973,29 +975,31 @@ sub Run {
 
         # get package from upload cache
         else {
-            my @AttachmentData = $Self->{UploadCachObject}->FormIDGetAllFilesData(
+            my @AttachmentData = $Self->{UploadCacheObject}->FormIDGetAllFilesData(
                 FormID => $FormID,
             );
             if ( !@AttachmentData || ( $AttachmentData[0] && !%{ $AttachmentData[0] } ) ) {
-                return $Self->{LayoutObject}->ErrorScreen( Message => 'Need File/Package!' );
+                $Errors{FileUploadInvalid} = 'ServerError';
             }
             else {
                 %UploadStuff = %{ $AttachmentData[0] };
             }
         }
-        my $Feedback
-            = $Self->{PackageObject}->PackageIsInstalled( String => $UploadStuff{Content} );
+        if ( !%Errors ) {
+            my $Feedback
+                = $Self->{PackageObject}->PackageIsInstalled( String => $UploadStuff{Content} );
 
-        if ($Feedback) {
-            return $Self->_UpgradeHandling(
+            if ($Feedback) {
+                return $Self->_UpgradeHandling(
+                    Package => $UploadStuff{Content},
+                    FormID  => $FormID,
+                );
+            }
+            return $Self->_InstallHandling(
                 Package => $UploadStuff{Content},
                 FormID  => $FormID,
             );
         }
-        return $Self->_InstallHandling(
-            Package => $UploadStuff{Content},
-            FormID  => $FormID,
-        );
     }
 
     # ------------------------------------------------------------ #
@@ -1027,192 +1031,205 @@ sub Run {
     # ------------------------------------------------------------ #
     # overview
     # ------------------------------------------------------------ #
-    else {
-        my %Frontend      = ();
-        my %NeedReinstall = ();
-        my %List          = ();
-        my $OutputNotify  = '';
-        if ( $Self->{ConfigObject}->Get('Package::RepositoryList') ) {
-            %List = %{ $Self->{ConfigObject}->Get('Package::RepositoryList') };
-        }
-        my %RepositoryRoot = ();
-        if ( $Self->{ConfigObject}->Get('Package::RepositoryRoot') ) {
-            %RepositoryRoot = $Self->{PackageObject}->PackageOnlineRepositories();
-        }
-        $Frontend{SourceList} = $Self->{LayoutObject}->OptionStrgHashRef(
-            Data => { %List, %RepositoryRoot, },
-            Name => 'Source',
-            Max  => 40,
-            SelectedID => $Source,
+    my %Frontend;
+    my %NeedReinstall;
+    my %List;
+    my $OutputNotify = '';
+    if ( $Self->{ConfigObject}->Get('Package::RepositoryList') ) {
+        %List = %{ $Self->{ConfigObject}->Get('Package::RepositoryList') };
+    }
+    my %RepositoryRoot;
+    if ( $Self->{ConfigObject}->Get('Package::RepositoryRoot') ) {
+        %RepositoryRoot = $Self->{PackageObject}->PackageOnlineRepositories();
+    }
+    $Frontend{SourceList} = $Self->{LayoutObject}->BuildSelection(
+        Data => { %List, %RepositoryRoot, },
+        Name => 'Source',
+        Max  => 40,
+        SelectedID => $Source,
+    );
+    $Self->{LayoutObject}->Block(
+        Name => 'Overview',
+        Data => { %Param, %Frontend, },
+    );
+    if ($Source) {
+        my @List = $Self->{PackageObject}->PackageOnlineList(
+            URL  => $Source,
+            Lang => $Self->{LayoutObject}->{UserLanguage},
         );
-        $Self->{LayoutObject}->Block(
-            Name => 'Overview',
-            Data => { %Param, %Frontend, },
-        );
-        if ($Source) {
-            my @List = $Self->{PackageObject}->PackageOnlineList(
-                URL  => $Source,
-                Lang => $Self->{LayoutObject}->{UserLanguage},
-            );
-            if ( !@List ) {
-                $OutputNotify .= $Self->{LayoutObject}->Notify( Priority => 'Error', );
-                if ( !$OutputNotify ) {
-                    $OutputNotify .= $Self->{LayoutObject}->Notify(
-                        Priority => 'Info',
-                        Info     => 'No Packages or no new Packages in selected Online Repository!',
-                    );
-                }
-            }
-
-            my $CssClass = 'searchactive';
-            for my $Data (@List) {
-
-                # set output class
-                $CssClass = $CssClass eq 'searchactive' ? 'searchpassive' : 'searchactive';
-
-                $Self->{LayoutObject}->Block(
-                    Name => 'ShowRemotePackage',
-                    Data => {
-                        %{$Data},
-                        Source   => $Source,
-                        CssClass => $CssClass,
-                    },
+        if ( !@List ) {
+            $OutputNotify .= $Self->{LayoutObject}->Notify( Priority => 'Error', );
+            if ( !$OutputNotify ) {
+                $OutputNotify .= $Self->{LayoutObject}->Notify(
+                    Priority => 'Info',
+                    Info     => 'No packages, or no new packages, found in selected repository.',
                 );
-
-                # show documentation link
-                my %DocFile = $Self->_DocumentationGet( Filelist => $Data->{Filelist} );
-                if (%DocFile) {
-                    $Self->{LayoutObject}->Block(
-                        Name => 'ShowRemotePackageDocumentation',
-                        Data => {
-                            %{$Data},
-                            Source => $Source,
-                            %DocFile,
-                        },
-                    );
-                }
-
-                if ( $Data->{Upgrade} ) {
-                    $Self->{LayoutObject}->Block(
-                        Name => 'ShowRemotePackageUpgrade',
-                        Data => { %{$Data}, Source => $Source, },
-                    );
-                }
-                elsif ( !$Data->{Installed} ) {
-                    $Self->{LayoutObject}->Block(
-                        Name => 'ShowRemotePackageInstall',
-                        Data => { %{$Data}, Source => $Source, },
-                    );
-                }
             }
+            $Self->{LayoutObject}->Block(
+                Name => 'NoDataFoundMsg',
+                Data => {},
+            );
+
         }
-        my $CssClass = 'searchactive';
-        for my $Package ( $Self->{PackageObject}->RepositoryList() ) {
 
-            # set output class
-            $CssClass = $CssClass eq 'searchactive' ? 'searchpassive' : 'searchactive';
-
-            my %Data = $Self->_MessageGet( Info => $Package->{Description} );
+        for my $Data (@List) {
 
             $Self->{LayoutObject}->Block(
-                Name => 'ShowLocalPackage',
+                Name => 'ShowRemotePackage',
                 Data => {
-                    %{$Package},
-                    %Data,
-                    Name     => $Package->{Name}->{Content},
-                    Version  => $Package->{Version}->{Content},
-                    Vendor   => $Package->{Vendor}->{Content},
-                    URL      => $Package->{URL}->{Content},
-                    CssClass => $CssClass,
+                    %{$Data},
+                    Source => $Source,
                 },
             );
 
             # show documentation link
-            my %DocFile = $Self->_DocumentationGet( Filelist => $Package->{Filelist} );
+            my %DocFile = $Self->_DocumentationGet( Filelist => $Data->{Filelist} );
             if (%DocFile) {
                 $Self->{LayoutObject}->Block(
-                    Name => 'ShowLocalPackageDocumentation',
+                    Name => 'ShowRemotePackageDocumentation',
                     Data => {
-                        Name    => $Package->{Name}->{Content},
-                        Version => $Package->{Version}->{Content},
+                        %{$Data},
+                        Source => $Source,
                         %DocFile,
                     },
                 );
             }
 
-            if ( $Package->{Status} eq 'installed' ) {
+            if ( $Data->{Upgrade} ) {
                 $Self->{LayoutObject}->Block(
-                    Name => 'ShowLocalPackageUninstall',
-                    Data => {
-                        %{$Package},
-                        Name    => $Package->{Name}->{Content},
-                        Version => $Package->{Version}->{Content},
-                        Vendor  => $Package->{Vendor}->{Content},
-                        URL     => $Package->{URL}->{Content},
-                    },
+                    Name => 'ShowRemotePackageUpgrade',
+                    Data => { %{$Data}, Source => $Source, },
                 );
-                if (
-                    !$Self->{PackageObject}->DeployCheck(
-                        Name    => $Package->{Name}->{Content},
-                        Version => $Package->{Version}->{Content}
-                    )
-                    )
-                {
-                    $NeedReinstall{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
-                    $Self->{LayoutObject}->Block(
-                        Name => 'ShowLocalPackageReinstall',
-                        Data => {
-                            %{$Package},
-                            Name    => $Package->{Name}->{Content},
-                            Version => $Package->{Version}->{Content},
-                            Vendor  => $Package->{Vendor}->{Content},
-                            URL     => $Package->{URL}->{Content},
-                        },
-                    );
-                }
             }
-            else {
+            elsif ( !$Data->{Installed} ) {
                 $Self->{LayoutObject}->Block(
-                    Name => 'ShowLocalPackageInstall',
-                    Data => {
-                        %{$Package},
-                        Name    => $Package->{Name}->{Content},
-                        Version => $Package->{Version}->{Content},
-                        Vendor  => $Package->{Vendor}->{Content},
-                        URL     => $Package->{URL}->{Content},
-                    },
+                    Name => 'ShowRemotePackageInstall',
+                    Data => { %{$Data}, Source => $Source, },
                 );
             }
         }
-
-        # show file upload
-        if ( $Self->{ConfigObject}->Get('Package::FileUpload') ) {
-            $Self->{LayoutObject}->Block(
-                Name => 'OverviewFileUpload',
-                Data => { FormID => $Self->{UploadCachObject}->FormIDCreate(), }
-            );
-        }
-
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Output .= $OutputNotify;
-        for ( sort keys %NeedReinstall ) {
-            $Output .= $Self->{LayoutObject}->Notify(
-                Priority => 'Error',
-                Data     => "$_ $NeedReinstall{$_}"
-                    . ' - $Text{"Package not correctly deployed! You should reinstall the Package again!"}',
-                Link => '$Env{"Baselink"}Action=$Env{"Action"}&Subaction=View&Name='
-                    . $_
-                    . '&Version='
-                    . $NeedReinstall{$_},
-            );
-        }
-        $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminPackageManager',
-        );
-        $Output .= $Self->{LayoutObject}->Footer();
-        return $Output;
     }
+
+    # if there are no remote packages to show, a msg is displayed
+    else {
+        $Self->{LayoutObject}->Block(
+            Name => 'NoDataFoundMsg',
+            Data => {},
+        );
+    }
+
+    # if there are no local packages to show, a msg is displayed
+    if ( !$Self->{PackageObject}->RepositoryList() ) {
+        $Self->{LayoutObject}->Block(
+            Name => 'NoDataFoundMsg2',
+            Data => {},
+        );
+    }
+
+    for my $Package ( $Self->{PackageObject}->RepositoryList() ) {
+
+        my %Data = $Self->_MessageGet( Info => $Package->{Description} );
+
+        $Self->{LayoutObject}->Block(
+            Name => 'ShowLocalPackage',
+            Data => {
+                %{$Package},
+                %Data,
+                Name    => $Package->{Name}->{Content},
+                Version => $Package->{Version}->{Content},
+                Vendor  => $Package->{Vendor}->{Content},
+                URL     => $Package->{URL}->{Content},
+            },
+        );
+
+        # show documentation link
+        my %DocFile = $Self->_DocumentationGet( Filelist => $Package->{Filelist} );
+        if (%DocFile) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ShowLocalPackageDocumentation',
+                Data => {
+                    Name    => $Package->{Name}->{Content},
+                    Version => $Package->{Version}->{Content},
+                    %DocFile,
+                },
+            );
+        }
+
+        if ( $Package->{Status} eq 'installed' ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ShowLocalPackageUninstall',
+                Data => {
+                    %{$Package},
+                    Name    => $Package->{Name}->{Content},
+                    Version => $Package->{Version}->{Content},
+                    Vendor  => $Package->{Vendor}->{Content},
+                    URL     => $Package->{URL}->{Content},
+                },
+            );
+            if (
+                !$Self->{PackageObject}->DeployCheck(
+                    Name    => $Package->{Name}->{Content},
+                    Version => $Package->{Version}->{Content}
+                )
+                )
+            {
+                $NeedReinstall{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
+                $Self->{LayoutObject}->Block(
+                    Name => 'ShowLocalPackageReinstall',
+                    Data => {
+                        %{$Package},
+                        Name    => $Package->{Name}->{Content},
+                        Version => $Package->{Version}->{Content},
+                        Vendor  => $Package->{Vendor}->{Content},
+                        URL     => $Package->{URL}->{Content},
+                    },
+                );
+            }
+        }
+        else {
+            $Self->{LayoutObject}->Block(
+                Name => 'ShowLocalPackageInstall',
+                Data => {
+                    %{$Package},
+                    Name    => $Package->{Name}->{Content},
+                    Version => $Package->{Version}->{Content},
+                    Vendor  => $Package->{Vendor}->{Content},
+                    URL     => $Package->{URL}->{Content},
+                },
+            );
+        }
+    }
+
+    # show file upload
+    if ( $Self->{ConfigObject}->Get('Package::FileUpload') ) {
+        $Self->{LayoutObject}->Block(
+            Name => 'OverviewFileUpload',
+            Data => {
+                FormID => $Self->{UploadCacheObject}->FormIDCreate(),
+                %Errors,
+            },
+        );
+    }
+
+    my $Output = $Self->{LayoutObject}->Header();
+    $Output .= $Self->{LayoutObject}->NavigationBar();
+    $Output .= $OutputNotify;
+    for my $ReinstallKey ( sort keys %NeedReinstall ) {
+        $Output .= $Self->{LayoutObject}->Notify(
+            Priority => 'Error',
+            Data     => "$ReinstallKey $NeedReinstall{$ReinstallKey}"
+                . ' - $Text{"Package not correctly deployed! You should reinstall the Package again!"}',
+            Link => '$Env{"Baselink"}Action=$Env{"Action"};Subaction=View;Name='
+                . $ReinstallKey
+                . ';Version='
+                . $NeedReinstall{$ReinstallKey},
+        );
+    }
+    $Output .= $Self->{LayoutObject}->Output(
+        TemplateFile => 'AdminPackageManager',
+    );
+    $Output .= $Self->{LayoutObject}->Footer();
+    return $Output;
 }
 
 sub _MessageGet {
@@ -1465,7 +1482,7 @@ sub _UpgradeHandling {
 
     my $IntroUpgradePre = $Self->{ParamObject}->GetParam( Param => 'IntroUpgradePre' ) || '';
 
-    # check if we have to show uninstall intro pre
+    # check if we have to show upgrade intro pre
     my %Structure = $Self->{PackageObject}->PackageParse( String => $Param{Package}, );
 
     # intro screen
