@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketActionCommon.pm - common file for several modules
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketActionCommon.pm,v 1.24 2010/11/16 11:04:09 mb Exp $
+# $Id: AgentTicketActionCommon.pm,v 1.33.2.1 2011/02/22 13:19:52 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -271,7 +271,7 @@ sub Run {
         next if !defined $GetParam{ $Prefix . 'Minute' };
         %GetParam = $Self->{LayoutObject}->TransfromDateSelection(
             %GetParam,
-            Prefix => $Prefix
+            Prefix => $Prefix,
         );
     }
 
@@ -427,88 +427,92 @@ sub Run {
             $Error{Expand} = 1;
         }
 
+        # ticket free text
+        my %TicketFreeText;
+        for my $Count ( 1 .. 16 ) {
+            my $Key  = 'TicketFreeKey' . $Count;
+            my $Text = 'TicketFreeText' . $Count;
+            $TicketFreeText{$Key} = $Self->{TicketObject}->TicketFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Key,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+            $TicketFreeText{$Text} = $Self->{TicketObject}->TicketFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Text,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+
+            # If Key has value 2, this means that the freetextfield is required
+            if ( $Self->{Config}->{TicketFreeText}->{$Count} == 2 ) {
+                $TicketFreeText{Required}->{$Count} = 1;
+            }
+
+            # check required FreeTextField (if configured)
+            if (
+                $Self->{Config}->{TicketFreeText}->{$Count} == 2
+                && $GetParam{$Text} eq ''
+                && $IsUpload == 0
+                )
+            {
+                $TicketFreeText{Error}->{$Count} = 1;
+                $Error{$Text} = 'ServerError';
+            }
+        }
+
+        my %TicketFreeTextHTML = $Self->{LayoutObject}->AgentFreeText(
+            Config => \%TicketFreeText,
+            Ticket => \%GetParam,
+        );
+
+        # ticket free time
+        my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate( Ticket => \%GetParam );
+
+        # article free text
+        my %ArticleFreeText;
+        for my $Count ( 1 .. 3 ) {
+            my $Key  = 'ArticleFreeKey' . $Count;
+            my $Text = 'ArticleFreeText' . $Count;
+            $ArticleFreeText{$Key} = $Self->{TicketObject}->ArticleFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Key,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+            $ArticleFreeText{$Text} = $Self->{TicketObject}->ArticleFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Text,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+
+            # If Key has value 2, this means that the field is required
+            if ( $Self->{Config}->{ArticleFreeText}->{$Count} == 2 ) {
+                $ArticleFreeText{Required}->{$Count} = 1;
+            }
+
+            # check required ArticleTextField (if configured)
+            if (
+                $Self->{Config}->{ArticleFreeText}->{$Count} == 2
+                && $GetParam{$Text} eq ''
+                && $IsUpload == 0
+                )
+            {
+                $ArticleFreeText{Error}->{$Count} = 1;
+                $Error{$Text} = 'ServerError';
+            }
+        }
+
+        my %ArticleFreeTextHTML = $Self->{LayoutObject}->TicketArticleFreeText(
+            Config  => \%ArticleFreeText,
+            Article => \%GetParam,
+        );
+
         # check errors
         if (%Error) {
 
-            # ticket free text
-            my %TicketFreeText;
-            for my $Count ( 1 .. 16 ) {
-                my $Key  = 'TicketFreeKey' . $Count;
-                my $Text = 'TicketFreeText' . $Count;
-                $TicketFreeText{$Key} = $Self->{TicketObject}->TicketFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Key,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-                $TicketFreeText{$Text} = $Self->{TicketObject}->TicketFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Text,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-
-                # If Key has value 2, this means that the freetextfield is required
-                if ( $Self->{Config}->{TicketFreeText}->{$Count} == 2 ) {
-                    $TicketFreeText{Required}->{$Count} = 1;
-                }
-
-                # check required FreeTextField (if configured)
-                if (
-                    $Self->{Config}->{TicketFreeText}->{$Count} == 2
-                    && $GetParam{$Text} eq ''
-                    && $IsUpload == 0
-                    )
-                {
-                    $TicketFreeText{Error}->{$Count} = 1;
-                }
-            }
-
-            my %TicketFreeTextHTML = $Self->{LayoutObject}->AgentFreeText(
-                Config => \%TicketFreeText,
-                Ticket => \%GetParam,
-            );
-
-            # ticket free time
-            my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate( Ticket => \%GetParam );
-
-            # article free text
-            my %ArticleFreeText;
-            for my $Count ( 1 .. 3 ) {
-                my $Key  = 'ArticleFreeKey' . $Count;
-                my $Text = 'ArticleFreeText' . $Count;
-                $ArticleFreeText{$Key} = $Self->{TicketObject}->ArticleFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Key,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-                $ArticleFreeText{$Text} = $Self->{TicketObject}->ArticleFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Text,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-
-                # If Key has value 2, this means that the field is required
-                if ( $Self->{Config}->{ArticleFreeText}->{$Count} == 2 ) {
-                    $ArticleFreeText{Required}->{$Count} = 1;
-                }
-
-                # check required ArticleTextField (if configured)
-                if (
-                    $Self->{Config}->{ArticleFreeText}->{$Count} == 2
-                    && $GetParam{$Text} eq ''
-                    && $IsUpload == 0
-                    )
-                {
-                    $ArticleFreeText{Error}->{$Count} = 1;
-                }
-            }
-            my %ArticleFreeTextHTML = $Self->{LayoutObject}->TicketArticleFreeText(
-                Config  => \%ArticleFreeText,
-                Article => \%GetParam,
-            );
             my $Output = $Self->{LayoutObject}->Header(
                 Type  => 'Small',
                 Value => $Ticket{TicketNumber},
@@ -703,6 +707,12 @@ sub Run {
                     my $ContentIDHTMLQuote = $Self->{LayoutObject}->Ascii2Html(
                         Text => $ContentID,
                     );
+
+                    # workaround for link encode of rich text editor, see bug#5053
+                    my $ContentIDLinkEncode = $Self->{LayoutObject}->LinkEncode($ContentID);
+                    $GetParam{Body} =~ s/(ContentID=)$ContentIDLinkEncode/$1$ContentID/g;
+
+                    # ignore attachment if not linked in body
                     next if $GetParam{Body} !~ /(\Q$ContentIDHTMLQuote\E|\Q$ContentID\E)/i;
                 }
 
@@ -971,7 +981,7 @@ sub _Mask {
             UserID => $Self->{UserID},
         );
         $Param{TypeStrg} = $Self->{LayoutObject}->BuildSelection(
-            Class => 'Validate_RequiredDropdown' . ( $Param{Errors}->{TypeIDInvalid} || ' ' ),
+            Class => 'Validate_Required' . ( $Param{Errors}->{TypeIDInvalid} || ' ' ),
             Data  => \%Type,
             Name  => 'TypeID',
             SelectedID   => $Param{TypeID},
@@ -1097,10 +1107,10 @@ sub _Mask {
 
         );
         if ( $Param{NewOwnerType} && $Param{NewOwnerType} eq 'Old' ) {
-            $Param{'NewOwnerType::Old'} = 'checked';
+            $Param{'NewOwnerType::Old'} = 'checked = "checked"';
         }
         else {
-            $Param{'NewOwnerType::New'} = 'checked';
+            $Param{'NewOwnerType::New'} = 'checked = "checked"';
         }
 
         $Self->{LayoutObject}->Block(
@@ -1296,6 +1306,10 @@ sub _Mask {
 
         # show spell check
         if ( $Self->{LayoutObject}->{BrowserSpellChecker} ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketOptions',
+                Data => {},
+            );
             $Self->{LayoutObject}->Block(
                 Name => 'SpellCheck',
                 Data => {},
@@ -1381,7 +1395,7 @@ sub _Mask {
         $Self->{LayoutObject}->Block(
             Name => 'TicketFreeTime',
             Data => {
-                TicketFreeTimeKey => $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count ),
+                TicketFreeTimeKey => $Param{ 'TicketFreeTimeKey' . $Count },
                 TicketFreeTime    => $Param{ 'TicketFreeTime' . $Count },
                 Count             => $Count,
             },
