@@ -1,8 +1,8 @@
 # --
 # Helper.pm - unit test helper functions
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: Helper.pm,v 1.4 2010/12/22 13:31:45 mg Exp $
+# $Id: Helper.pm,v 1.7.2.1 2011/02/14 13:24:51 cg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,6 +15,7 @@ use strict;
 
 use Kernel::Config;
 use Kernel::System::User;
+use Kernel::System::Group;
 use Kernel::System::SysConfig;
 
 =head1 NAME
@@ -70,6 +71,12 @@ sub new {
         ConfigObject => $Self->{ConfigObject},
     );
 
+    $Self->{GroupObject} = Kernel::System::Group->new(
+        %{ $Self->{UnitTestObject} },
+        ConfigObject => $Self->{ConfigObject},
+        UserObject   => $Self->{UserObject},
+    );
+
     #
     # Make backup of system configuration if needed
     #
@@ -84,13 +91,27 @@ sub new {
     return $Self;
 }
 
+=item GetRandomID()
+
+creates a random ID that can be used in tests as a unique identifier.
+
+=cut
+
+sub GetRandomID {
+    my ( $Self, %Param ) = @_;
+
+    return 'test-' . int( rand(1000000) )
+}
+
 =item TestUserCreate()
 
 creates a test user that can be used in the Selenium tests. It will
 be set to invalid automatically during the constructor. Returns
 the login name of the new user, the password is the same.
 
-    my $TestUserLogin = $sel->TestUserCreate();
+    my $TestUserLogin = $sel->TestUserCreate(
+        Groups => ['admin', 'users'],           # optional, list of groups to add this user to (rw rights)
+    );
 
 =cut
 
@@ -106,7 +127,7 @@ sub TestUserCreate {
     }
 
     # create test user
-    my $TestUserLogin = 'selenium-test-user' . int( rand(1000000) );
+    my $TestUserLogin = $Self->GetRandomID();
 
     my $TestUserID = $Self->{UserObject}->UserAdd(
         UserFirstname => $TestUserLogin,
@@ -125,6 +146,29 @@ sub TestUserCreate {
 
     $Self->{UnitTestObject}->True( 1, "Created test user $TestUserID" );
 
+    # Add user to groups
+    GROUP_NAME:
+    for my $GroupName ( @{ $Param{Groups} || [] } ) {
+        my $GroupID = $Self->{GroupObject}->GroupLookup( Group => $GroupName );
+        die "Cannot find group $GroupName" if ( !$GroupID );
+
+        $Self->{GroupObject}->GroupMemberAdd(
+            GID        => $GroupID,
+            UID        => $TestUserID,
+            Permission => {
+                ro        => 1,
+                move_into => 1,
+                create    => 1,
+                owner     => 1,
+                priority  => 1,
+                rw        => 1,
+            },
+            UserID => 1,
+        ) || die "Could not add test user $TestUserLogin to group $GroupName";
+
+        $Self->{UnitTestObject}->True( 1, "Added test user $TestUserLogin to group $GroupName" );
+    }
+
     return $TestUserLogin;
 }
 
@@ -215,6 +259,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.4 $ $Date: 2010/12/22 13:31:45 $
+$Revision: 1.7.2.1 $ $Date: 2011/02/14 13:24:51 $
 
 =cut
