@@ -1,7 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
 # scripts/restore.pl - the restore script
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: restore.pl,v 1.13 2010/12/13 13:23:22 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -15,30 +17,24 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
-use strict;
-use warnings;
-
 # use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
 use lib dirname($RealBin) . "/Kernel/cpan-lib";
 
+use strict;
+use warnings;
+
 use vars qw($VERSION);
+$VERSION = qw($Revision: 1.13 $) [1];
 
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
-
 # get options
 my %Opts;
 my $DB     = '';
@@ -46,7 +42,7 @@ my $DBDump = '';
 getopt( 'hbd', \%Opts );
 if ( exists $Opts{h} ) {
     print "restore.pl <Revision $VERSION> - restore script\n";
-    print "Copyright (C) 2001-2013 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
     print "usage: restore.pl -b /data_backup/<TIME>/ -d /opt/otrs/\n";
     exit 1;
 }
@@ -74,6 +70,13 @@ if ( -e "$Opts{b}/Config.tar.gz" ) {
     system("tar -xzf $Opts{b}/Config.tar.gz");
 }
 
+require Kernel::Config;
+require Kernel::System::Encode;
+require Kernel::System::Time;
+require Kernel::System::Log;
+require Kernel::System::Main;
+require Kernel::System::DB;
+
 # create common objects
 my %CommonObject;
 $CommonObject{ConfigObject} = Kernel::Config->new();
@@ -109,11 +112,11 @@ else {
 # check needed programs
 for my $CMD ( 'cp', 'tar', $DBDump ) {
     my $Installed = 0;
-    open( my $Input, '-|', "which $CMD" );    ## no critic
-    while (<$Input>) {
+    open( IN, "which $CMD | " );
+    while (<IN>) {
         $Installed = 1;
     }
-    close $Input;
+    close IN;
     if ( !$Installed ) {
         print STDERR "ERROR: Can't locate $CMD!\n";
         exit 1;
@@ -191,13 +194,13 @@ if ( $DB =~ m/mysql/i ) {
     }
     elsif ( -e "$Opts{b}/DatabaseBackup.sql.bz2" ) {
         print "decompresses SQL-file ...\n";
-        system("bunzip2 $Opts{b}/DatabaseBackup.sql.bz2");
+        system("bunzip $Opts{b}/DatabaseBackup.sql.bz2");
         print "cat SQL-file into $DB database\n";
         system(
             "mysql -f -u$DatabaseUser $DatabasePw -h$DatabaseHost $Database < $Opts{b}/DatabaseBackup.sql"
         );
         print "compress SQL-file...\n";
-        system("bzip2 $Opts{b}/DatabaseBackup.sql");
+        system("bzip $Opts{b}/DatabaseBackup.sql");
     }
 }
 else {
@@ -213,12 +216,12 @@ else {
     }
     elsif ( -e "$Opts{b}/DatabaseBackup.sql.bz2" ) {
         print "decompresses SQL-file ...\n";
-        system("bunzip2 $Opts{b}/DatabaseBackup.sql.bz2");
+        system("bunzip $Opts{b}/DatabaseBackup.sql.bz2");
         print "cat SQL-file into $DB database\n";
         system(
             "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser -W'$DatabasePw' -h$DatabaseHost $Database"
         );
         print "compress SQL-file...\n";
-        system("bzip2 $Opts{b}/DatabaseBackup.sql");
+        system("bzip $Opts{b}/DatabaseBackup.sql");
     }
 }
